<?php
/*
Plugin Name: Sadad QA Payment
Version: 1.17
Description: This plugin using visitors to pay via Sadad.
Author: Sadad Developer
Author URI: https://sadad.qa/
*/
define('SADAD_PLUGIN_PATH', plugin_dir_path(__FILE__));
require_once(SADAD_PLUGIN_PATH . 'include/functions.php');
define('SADAD_PLUGIN_URl', __FILE__);
add_action('plugins_loaded', 'WC_sadadpay_init');

function WC_sadadpay_init()
{
    
    if (!class_exists('WC_Payment_Gateway'))
        return;
    
    if (isset($_GET['msg'])) {
        add_action('the_content', 'SadadPayShowMsg');
    }
    
    function SadadPayShowMsg($content)
    {
        return '<div class="box ' . htmlentities($_GET['type']) . '-box">' . htmlentities(urldecode($_GET['msg'])) . '</div>' . $content;
    }
    
    /**
     * WC_Gateway_sadadpay class
     */
    class WC_Gateway_sadadpay extends WC_Payment_Gateway
    {
        
        protected $msg = array();
        
        /**
         * Constructor for the gateway.
         */
        public function __construct()
        {
            
            $this->id                 = 'sadadpay';
            $this->has_fields         = false;
            //$this->order_button_text = __('Pay', 'woocommerce');
            $this->method_title       = __('Pay With Sadad');
            $this->method_description = __('Your Payment pay with sadad.');
            $this->icon               = WP_PLUGIN_URL . "/" . plugin_basename(dirname(__FILE__)) . '/images/logo.png';
            $this->init_form_fields();
            $this->init_settings();
            $this->title = "Pay With Sadad";
            $this->description = "This is secure 256-bit SSL encrypted payment, You are safe with Qatar's First Payment gateway.";
            $this->merchantID = $this->settings['merchantID'];
            $this->merchant_key = $this->settings['merchant_key'];
            $this->website = $this->settings['website'];
            $this->mode = $this->settings['mode'];
            $this->language = $this->settings['language'];
            $this->callbackurl = $this->settings['callbackurl'];
            $this->checkoutType = $this->settings['checkoutType'];
            $this->checkout2Type = $this->settings['checkout2Type'];
            $this->checkoutloader = $this->settings['checkoutloader'];
            $this->log            = $this->settings['log'];
            $this->msg['message'] = "";
            $this->msg['class']   = "";
            
            add_action('init', array(
                &$this,
                'capture_sadad_response'
            ));
            
            add_action('woocommerce_api_' . strtolower(get_class($this)), array(
                $this,
                'capture_sadad_response'
            ));
            add_action('woocommerce_update_options_payment_gateways_' . $this->id, array(
                &$this,
                'process_admin_options'
            ));
            add_action('woocommerce_receipt_' . $this->id, array(
                &$this,
                'receipt_page'
            ));
            wp_enqueue_style('woo-sadad-payment-gateway', plugins_url('/stylesadad.css', SADAD_PLUGIN_URl), array(), WC_VERSION);
        }
        
        function init_form_fields()
        {
            $this->form_fields = array(
                'enabled' => array(
                    'title' => __('Enable/Disable'),
                    'type' => 'checkbox',
                    'label' => __('Enable Sadad Payment Gateway.'),
                    'default' => 'no'
                ),
                //                'title' => array(
                //                    'title' => __('Title:'),
                //                    'type' => 'text',
                //                    'description' => __('This controls the title which the user sees during checkout.'),
                //                    'default' => __('pay with sadad')),
                //                'description' => array(
                //                    'title' => __('Description:'),
                //                    'type' => 'textarea',
                //                    'description' => __('This controls the description which the user sees during checkout.'),
                //                    'default' => __("The best payment gateway provider in Qatar for e-payment through Sadad, credit card, debit card.<br />This is secure 256-bit SSL Encrypted payment. You're safe.")),
                'merchantID' => array(
                    'title' => __('Merchant ID'),
                    'type' => 'text',
                    'description' => __('This is the Sadad id given by Sadad.')
                ),
                'merchant_key' => array(
                    'title' => __('Merchant Key'),
                    'type' => 'text',
                    'description' => __('This is the Secret key.')
                ),
                'website' => array(
                    'title' => __('Website'),
                    'type' => 'text',
                    'description' => __('')
                ),
                'language' => array(
                    'title' => __('Language'),
                    'type' => 'select',
                    'options' => array(
                        'arb' => 'Arabic',
                        'eng' => 'English'
                    ),
                    'label' => __('Select language'),
                    'description' => "Select the language for payment gateway page.",
                    'default' => 'arb'
                ),
                'callbackurl' => array(
                    'title' => __('Set CallBack URL'),
                    'type' => 'select',
                    'options' => array(
                        'yes' => 'yes'
                    ),
                    'label' => __('Select to enable Sandbox Enviroment'),
                    'description' => "",
                    'default' => 'yes'
                ),
                
                'checkoutType' => array(
                    'title' => __('Checkout Type'),
                    'type' => 'select',
                    'options' => array(
                        '1' => 'Web checkout',
                        '2' => 'Web checkout 2.2'
                    ),
                    
                    'default' => '1'
                ),
                'checkout2Type' => array(
                    'title' => __('Checkout 2.2 Type'),
                    'type' => 'select',
                    'options' => array(
                        '2' => 'Iframe',
                        '1' => 'Modal Popup'
                    ),
                    
                    'default' => '1'
                ),
                'checkoutloader' => array(
                    'title' => __('Hide Loader'),
                    'type' => 'select',
                    'options' => array(
                        'NO' => 'NO',
                        'YES' => 'YES'
                    ),
                    'description' => "Hide loader on Sadad checkout page",
                    'default' => 'YES'
                ),
                'mode' => array(
                    'title' => __('Enable Test Mode'),
                    'type' => 'select',
                    'options' => array(
                        'yes' => 'yes'
                    ),
                    'label' => __('Select to enable Sandbox Enviroment'),
                    'description' => "",
                    'default' => 'yes'
                ),
                'log' => array(
                    'title' => __('Do you want to log'),
                    'type' => 'checkbox',
                    'label' => __('Select to enable Log'),
                    'default' => "no"
                )
            );
        }
        
        /**
         *  Payment form on checkout page.
         * */
        function payment_fields()
        {
            $description = $this->get_description();
            if ($description) {
                echo wpautop(wptexturize(trim($description)));
            }
        }
        
        public function is_valid_for_use()
        {
            return in_array(get_woocommerce_currency(), apply_filters('woocommerce_paypal_supported_currencies', array(
                'QAR'
            )), true);
        }
        
        /**
         * Admin Panel Options
         * - Options for bits like 'title' and availability on a country-by-country basis
         * */
        public function admin_options()
        {
            if ($this->is_valid_for_use()) {
                echo '<h3>' . __('Sadad Payment Gateway') . '</h3>';
                echo '<p>' . __('Qatar online payment solutions for all your transactions by sadad') . '</p>';
                echo '<table class="form-table">';
                $this->generate_settings_html();
                echo '</table>';
?>
                   <script>
                        jQuery(document).ready(function($){
                            if($('#woocommerce_sadadpay_checkoutType').val()==1){
                                $('#woocommerce_sadadpay_checkout2Type').parent().parent().parent().hide();
                                //$('#woocommerce_sadadpay_checkoutloader').parent().parent().parent().hide();
                                
                            }
                            $('#woocommerce_sadadpay_checkoutType').on('change',function(){
                                $('#woocommerce_sadadpay_checkout2Type').parent().parent().parent().toggle();
                                //$('#woocommerce_sadadpay_checkoutloader').parent().parent().parent().toggle();
                            });
                        });
                    </script>
                <?php
            } else {
?>
               <div class="inline error">
                    <p>
                        <strong><?php
                esc_html_e('Gateway disabled', 'woocommerce');
?></strong>: <?php
                esc_html_e('Sadad does not support your store currency.', 'woocommerce');
?>
                   </p>
                </div>
                <?php
            }
        }
        
        /**
         * Return the gateway's description.
         *
         * @return string
         */
        public function get_description()
        {
            return apply_filters('woocommerce_gateway_description', $this->description, $this->id);
        }
        
        /**
         * Receipt Page
         * */
        function receipt_page($order)
        {
            echo $this->generate_sadad_form($order);
        }
        
        /**
         * Process the payment and return the result
         * */
        function process_payment($order_id)
        {
            if (version_compare(WOOCOMMERCE_VERSION, '2.0.0', '>=')) {
                $order = new WC_Order($order_id);
            } else {
                $order = new woocommerce_order($order_id);
            }
            return array(
                'result' => 'success',
                'redirect' => add_query_arg('order-pay', $order->get_id(), add_query_arg('key', $order->get_order_key(), $order->get_checkout_payment_url(true)))
            );
            
        }
        
        /**
         * Check for valid sadad server callback // response processing //
         * */
        function capture_sadad_response()
        {
            wcgddrd_chck_session();
            global $woocommerce;
            if (isset($_POST['ORDERID']) && isset($_POST['RESPCODE'])) {
                $order_sent          = sanitize_text_field($_POST['ORDERID']);
                $responseDescription = sanitize_text_field($_POST['RESPMSG']);
                if (version_compare(WOOCOMMERCE_VERSION, '2.0.0', '>=')) {
                    $order = new WC_Order($_POST['ORDERID']);
                } else {
                    $order = new woocommerce_order($_POST['ORDERID']);
                }

                
                if ($this->log == "yes") {
                    error_log("Response Code = " . sanitize_text_field($_POST['RESPCODE']));
                }
                
                $redirect_url         = $order->get_checkout_order_received_url();
                $this->msg['class']   = 'error';
                $this->msg['message'] = "Thank you for shopping with us. However, the transaction has been Failed For Reason  : " . $responseDescription;
                if ($_POST['RESPCODE'] == 01) {
                    
                    $order_amount = $order->get_total();
                    
                    if ((sanitize_text_field($_POST['TXNAMOUNT']) == $order_amount)) {
                        
                        if ($this->log == "yes") {
                            error_log("amount matched");
                        }
                        
                        $order_sent          = sanitize_text_field($_POST['ORDERID']);
                        $res_code            = sanitize_text_field($_POST['RESPCODE']);
                        $responseDescription = sanitize_text_field($_POST['RESPMSG']);
                        $order_amount        = sanitize_text_field($_POST['TXNAMOUNT']);
                        
                        $requestParamList = array(
                            "MID" => $this->merchantID,
                            "ORDERID" => $order_sent
                        );
                        
                        $checksum_response = $_POST['checksumhash'];
                        unset($_POST['checksumhash']);
                        $sadad_id                   = $this->merchantID;
                        $sadad_secrete_key          = trim($this->merchant_key);
                        $data_repsonse              = array();
                        $data_repsonse['postData']  = $_POST;
                        $data_repsonse['secretKey'] = $this->merchant_key;
                        $key                        = $sadad_secrete_key . $sadad_id;
                        if (verifychecksum_eFromStr(json_encode($data_repsonse), $key, $checksum_response) === "TRUE") {
                            
                            if ($_POST['STATUS'] == 'TXN_SUCCESS' && $_POST['TXNAMOUNT'] == $order_amount) {
                                
                                if ($order->has_status('pending')) {
                                    $this->msg['message'] = "Thank you for your order. Your " . $_POST['transaction_number'] . " transaction has been successful.";
                                    $this->msg['class']   = 'success';
                                    
                                    if ($order->has_status('processing')) {
                                        
                                    } else {
                                        $order->payment_complete();
                                        $order->add_order_note('Mobile Wallet payment successful');
                                        $order->add_order_note($this->msg['message']);
                                        $tnx_id_msg = "Sadad TNX ID: " . $_POST['transaction_number'];
                                        $order->add_order_note($tnx_id_msg);
                                        $woocommerce->cart->empty_cart();
                                        update_post_meta($order->get_id(), '_transaction_id', $_POST['transaction_number']);
                                    }
                                }
                            } else {
                                $this->msg['class']   = 'error';
                                $this->msg['message'] = "It seems some issue in server to server communication. Kindly connect with administrator.";
                                $order->update_status('failed');
                                $order->add_order_note('Failed 1');
                                $order->add_order_note($this->msg['message']);
                            }
                        } else {
                            $this->msg['class']   = 'error';
                            $this->msg['message'] = "Checksum didn't match";
                            $order->update_status('failed');
                            $order->add_order_note('Failed 1');
                            $order->add_order_note($this->msg['message']);
                        }
                    } else {
                        
                        $this->msg['class']   = 'error';
                        $this->msg['message'] = "Order Mismatch Occur";
                        $order->update_status('failed');
                        $order->add_order_note('Failed 2');
                        $order->add_order_note($this->msg['message']);
                    }
                } else {
                    $order->update_status('failed');
                    $order->add_order_note('Failed 3');
                    $order->add_order_note($responseDescription);
                    $order->add_order_note($this->msg['message']);
                }
                
                $redirect_url = $order->get_checkout_order_received_url();
                
                $redirect_url = add_query_arg(array('msg' => urlencode($this->msg['message']), 'type' => $this->msg['class']), $redirect_url);
                
				 $_SESSION['sadad_redirect'] = $redirect_url;
				
                wp_redirect($redirect_url);
                exit;
            }
        }
        
        /**
         * Generate sadad button link
         * */
        public function generate_sadad_form($order_id)
        {
            global $woocommerce;
            $txnDate      = date('Y-m-d');
            $milliseconds = (int) (1000 * (strtotime(date('Y-m-d'))));
            
            if (version_compare(WOOCOMMERCE_VERSION, '2.0.0', '>=')) {
                $order = new WC_Order($order_id);
            } else {
                $order = new woocommerce_order($order_id);
            }
            
            //Check if order already paid
            if ($order->is_paid())
                return;
            //Set to pending so that if user order failed for a reason and he's trying again for same order.
			$order->update_status('pending');
			
            $redirect_url = $this->get_return_url($order);
            
            $a = strstr($redirect_url, "?");
            if ($a) {
                $redirect_url .= "&wc-api=WC_Gateway_sadadpay";
            } else {
                $redirect_url .= "?wc-api=WC_Gateway_sadadpay";
            }
            error_log("redirect url = this {$redirect_url}");
            //////////////
            $order_id           = $order->get_id();
            $Order_Total        = $order->get_total();
            $txntype            = '1';
            $ptmoption          = '1';
            $currency           = get_woocommerce_currency();
            $purpose            = "1";
            $productDescription = 'sadadpay';
            
            
            $ip = $_SERVER['REMOTE_ADDR'];
            
            $email     = $order->get_billing_email();
            $mobile_no = $order->get_billing_phone();
            
            $post_params = Array(
                "MID" => $this->merchantID,
                "ORDER_ID" => $order_id,
                "TXN_AMOUNT" => $Order_Total,
                "CUST_ID" => $email,
                "WEBSITE" => $this->website,
                "MOBILE_NO" => $mobile_no
            );
            if ($this->callbackurl == 'yes') {
                $checkout_url = wc_get_checkout_url();
                $b            = strstr($checkout_url, "?");
                if ($b) {
                    $post_params["CALLBACK_URL"] = $checkout_url . "&wc-api=WC_Gateway_sadadpay";
                } else {
                    $post_params["CALLBACK_URL"] = $checkout_url . "wc-api/WC_Gateway_sadadpay";
                }
            }
            $all = '';
            foreach ($post_params as $name => $value) {
                if ($name != 'checksum') {
                    $all .= "'";
                    if ($name == 'returnUrl') {
                        $all .= $value;
                    } else {
                        
                        $all .= $value;
                    }
                    $all .= "'";
                }
            }
            if ($this->log == "yes") {
                error_log("AllParams : " . $all);
            }
            
            $sadad__checksum_data = array();
          
            
            $order_items   = $order->get_items(array(
                'line_item'
            )); // line_item | fee | shipping
            
            $sadad_checksum_array = array();
            $incVal               = 0;
            
            if (!is_wp_error($order_items)) {
                foreach ($order_items as $item_id => $order_item) {
                    //$item_meta          = strip_tags(wc_display_item_meta($order_item, array(
//                        'before' => '(',
//                        'separator' => ', ',
//                        'after' => ')',
//                        'echo' => false,
//                        'autop' => false
//                    )));
					
                    $product            = wc_get_product($order_item['product_id']);
                    
                    
                    $sadad_checksum_array['productdetail'][$incVal]['order_id']    = (string) $order_item->get_order_id();
                    $sadad_checksum_array['productdetail'][$incVal]['itemname']    = html_entity_decode($order_item->get_name());		
                    $sadad_checksum_array['productdetail'][$incVal]['amount']      = $product->get_price();
                    $sadad_checksum_array['productdetail'][$incVal]['totalamount'] = $order_item->get_total();
                    $sadad_checksum_array['productdetail'][$incVal]['quantity']    = (string) $order_item->get_quantity();
                    $sadad_checksum_array['productdetail'][$incVal]['type']        = $order_item->get_type();
                    //$sadad_checksum_array['productdetail'][$incVal]['item_meta']   = $item_meta;
                    $incVal++;
                }
            }
            
            if ($this->callbackurl == 'yes') {
                $checkout_url = wc_get_checkout_url();
                $a            = strstr($checkout_url, "?");
                if ($a) {
                    $call = $checkout_url . "&wc-api=WC_Gateway_sadadpay";
                } else {
                    $call = $checkout_url . "wc-api/WC_Gateway_sadadpay";
                }
            }
            $txnDate = date('Y-m-d H:i:s');
            
			
			//Urlencode the secret key
			$secretKeyy = trim($this->merchant_key);
            
            $sadad_checksum_array['merchant_id']                     = $this->merchantID;
            $sadad_checksum_array['ORDER_ID']                        = (string) $order_id;
            $sadad_checksum_array['WEBSITE']                         = $this->website;
            $sadad_checksum_array['TXN_AMOUNT']                      = $Order_Total;
            //$sadad_checksum_array['shipping_rate']                   = $order->get_shipping_total();
            $sadad_checksum_array['CUST_ID']                         = $email;
			$sadad_checksum_array['VERSION']                         = '1.1';
            $sadad_checksum_array['EMAIL']                           = $email;
            $sadad_checksum_array['MOBILE_NO']                       = $mobile_no;
            $sadad_checksum_array['MODE']                            = (string) $this->mode;
            $sadad_checksum_array['SADAD_WEBCHECKOUT_PAGE_LANGUAGE'] = $this->language;
            $sadad_checksum_array['CALLBACK_URL']                    = $call;
            $sadad_checksum_array['txnDate']                         = $txnDate;
			$sadad_checksum_array['SADAD_WEBCHECKOUT_HIDE_LOADER'] = $this->checkoutloader;
            
            //if webcheckout 2.2, add these fields to checksum
            if ($this->checkoutType == 2) {
                $sadad_checksum_array['showdialog']                    = $this->checkout2Type;
            }
			
			$sAry1 = array();
			$sadad_checksum_array1 = array();
			foreach($sadad_checksum_array as $pK => $pV){
				if($pK=='checksumhash') continue;
				if(is_array($pV)){
					$prodSize = sizeof($pV);
					for($i=0;$i<$prodSize;$i++){
						foreach($pV[$i] as $innK => $innV){
							$sAry1[] = "<input type='hidden' name='productdetail[$i][". $innK ."]' value='" . trim($innV) . "'/>";
							$sadad_checksum_array1['productdetail'][$i][$innK]    = trim($innV);
						}
					}
				} else {
					$sAry1[] = "<input type='hidden' name='". $pK ."' id='". $pK ."' value='" . trim($pV) . "'/>";
					$sadad_checksum_array1[$pK]    = trim($pV);
				}
			}
            
            $sadad__checksum_data['postData']  = $sadad_checksum_array1;
            $sadad__checksum_data['secretKey'] = $secretKeyy;
            $checksum                          = getChecksumFromString(json_encode($sadad__checksum_data), $secretKeyy . $this->merchantID);
			$sAry1[]                = "<input type='hidden' name='checksumhash' value='" . $checksum . "'/>";
            
            if ($this->checkoutType == 1) {
                $action_url = 'https://sadadqa.com/webpurchase';
                
                return '<form action="' . $action_url . '" method="post" id="sadad_payment_form" name="gosadad">
                    ' . implode('', $sAry1) . '
                    <script type="text/javascript">
                        document.gosadad.submit();
                    </script>
                    
                </form>';
            } else {
                $action_url = 'https://secure.sadadqa.com/webpurchasepage';
                
                echo '<form action="' . $action_url . '" method="post" id="paymentform" name="paymentform" data-link="' . $action_url . '">
                    ' . implode('', $sAry1) . '
                </form>';
                
                $redirect_url = $order->get_checkout_order_received_url();
?>
               
                <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.12.9/umd/popper.min.js" integrity="sha384-ApNbgh9B+Y1QKtv3Rn7W3mgPxhU9K/ScQsAP7hUibX39j7fakFPskvXusvfa0b4Q" crossorigin="anonymous"></script>
                
                <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js" integrity="sha384-JZR6Spejh4U02d8jOt6vLEHfe/JQGiRRSQQxSfFWpi1MquVdAyjUar5+76PVCmYl" crossorigin="anonymous"></script>
                
                <script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-modal/2.2.6/js/bootstrap-modal.min.js"></script>
                
                <script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-modal/2.2.6/js/bootstrap-modalmanager.js"></script>
                
                <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-modal/2.2.6/css/bootstrap-modal.min.css" crossorigin="anonymous">
                
                <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-modal/2.2.6/css/bootstrap-modal-bs3patch.min.css" crossorigin="anonymous">
                
                    <style>
                        .close-btn{
                            height: auto;
                            width: auto;
                            -webkit-appearance: none !important;
                            background: none !important;
                            border: 0px;
                            position: absolute;
                            right: 10px;
                            z-index: 11;
                            cursor: pointer;
                            outline: 0px !important;
                            box-shadow: none;
                            top: 15px;
                        }
                        .close, .close:hover{
                            color: #000;
                            font-size:30px;
                        }
                        .modal-body{
                            padding: 0px;
                            border-radius: 15px;
                        }
                        #onlyiframe{
                         width:100% !important;
                         height:100vh !important;
                         overflow: hidden !important;
                         border:0;
                        
                         top: 0;
                         left: 0;
                         bottom: 0;
                         right: 0;
                              
                        }
                        #includeiframe{
                            height:100vh !important;
                         overflow: hidden !important;
                        border:0;
                        }
                        .modal-backdrop {
                           background-color: #000 !important;
                        }
						ul.order_details{
							display: none !important;
						}
                    </style>
                    <!-- Modal -->
                    <div id="container_div_sadad">
                    <div class="modal fade not_hide_sadad" id="exampleModal" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
                        <div class="modal-dialog" role="document">
                            <div class="modal-content">
                                <button type="button" class="close-btn" onClick="closemodal();" aria-label="Close">
                                    <span class="close">&times;</span>
                                </button>
                                <div class="modal-body">
                                    <iframe name="includeiframe" id="includeiframe" frameborder="0" scrolling="no"></iframe>
                                </div>
                            </div>
                        </div>
                    </div>
                    <iframe name="onlyiframe" id="onlyiframe" border="0" class="not_hide_sadad" frameborder="0" scrolling="no"></iframe>
                    </div>
                    
                    <script>
                        function closemodal()
                        {
                            //$('#exampleModal').modal('hide');
							window.location.href='<?php echo wc_get_checkout_url(); ?>';
                        }
                        jQuery(document).ready(function($){
                        
                                if ($('#showdialog').val() == 1) {
                                
                                      $('#exampleModal').modal('show');
                                      $('#paymentform').attr('target', 'includeiframe').submit();
                                      $('#onlyiframe').remove();
                                    
                                } else {
                                     $('#exampleModal').remove();
                                     $('#paymentform').attr('target', 'onlyiframe').submit();
                                    
                                }
                             $('iframe').load(function() {
                                    $(this).height( $(this).contents().find("body").height() );
                                    if(this.contentWindow.location=='<?php
                echo $call;
?>'){
									
									$(this).hide();
									$.ajax({
													type: "POST",
													url: "<?php echo site_url(); ?>/wp-admin/admin-ajax.php",
													data: 'action=get_current_order_redirect',
													success: function(response){
														window.location.href= response;
													}
									});
                                        
                                    }
                                });    
                        });
                    </script>

                <?php
                
            }
        }
        
    }
    
    /**
     * Add the Gateway to WooCommerce
     * */
    function woocommerce_add_sadad_gateway($methods)
    {
        $methods[] = 'WC_Gateway_sadadpay';
        return $methods;
    }
    
    add_filter('woocommerce_payment_gateways', 'woocommerce_add_sadad_gateway');
    
    function woocommerce_sadad_order_button_html($button_html)
    {
        $order_button_text = 'Pay';
        $btn_img           = WP_PLUGIN_URL . "/" . plugin_basename(dirname(__FILE__)) . '/images/pay.png';
        $button_html       = '<button type="submit" class="button alt" name="woocommerce_checkout_place_order" id="place_order">Pay Now</button>';
        //<img src="' . $btn_img . '" style="display:inline;">
        return $button_html;
    }
    
    add_filter('woocommerce_order_button_html', 'woocommerce_sadad_order_button_html');
	function wcgddrd_chck_session()
    {
	    if (session_status() == PHP_SESSION_NONE) {
            @session_start();
        }
    }
	
	function wcgddrd_get_ord_url(){
		wcgddrd_chck_session();
		if(isset($_SESSION['sadad_redirect'])){
			echo $_SESSION['sadad_redirect'];
		} else {
			echo site_url('/shop');
		}
		die();
	}
 add_action( 'wp_ajax_nopriv_get_current_order_redirect', 'wcgddrd_get_ord_url' );
  add_action( 'wp_ajax_get_current_order_redirect', 'wcgddrd_get_ord_url' );
}
?>